#!/bin/sh

#   This UNIX script can be passed two arguments.  The first argument is
#   mandatory. The 1st argument must be a url to a single
#   JSP page or a url to a directory containing JSP pages.
#   The second argument is optional. The 2nd argument is "-s".
#   If the first argument denotes a directory then the second argument
#   tells the JSP Compiler to compile all JSP pages in all
#   sub-directories of that directory.
#   If no arguments are passed to this script then a usage information
#   is displayed.
#
#   If you place this script file (and JSPCompiler.jar)
#   in your ServletExec installation
#   folder, you will not have to make as many edits to it.
#   For example, with a ServletExec AS installation, place this file
#   and JSPCompiler.jar at
#   /usr/local/NewAtlanta/ServletExecAS/

#   Here are some examples of invoking this batch file:
#       jspc /sales/index.jsp  - compile a single JSP page 
#       jspc /sales/           - compile all of the JSPs in a directory
#       jspc /sales/ -s        - compile all of the JSPs in a directory and its sub-directories
#
#   For all the examples above, the folder named 'sales' would need to be inside the root directory.
#
#       jspc / -s              - compile all of the JSPs in the root directory and all of its sub-directories.

#   The following need to be sent to match your environment.
#       JDK_HOME - path to JDK home directory
#       SE_LIB   - path to ServletExec lib directory
#       WORK_DIR - path to directory where generated .java and .class files will be placed
#       ROOT_DIR - path to root document directory where JSP pages are located
#       JSP_EXT  - the extension used with JSP pages (normally .jsp)

JDK_HOME="/usr/java"
SE_LIB="./lib"
WORK_DIR="./work"
ROOT_DIR="./docs"
JSP_EXT=".jsp"
JARS="$SE_LIB/ServletExec41.jar:$SE_LIB/servlet.jar:$SE_LIB/jndi.jar:$SE_LIB/jaxp.jar:$SE_LIB/crimson.jar:$JDK_HOME/lib/tools.jar:./JSPCompiler.jar"
RECURSE_FLAG=""

#
# fetch the arguments
#
while getopts s opt
do
  case $opt in    
    s) RECURSE_FLAG="-s"
       ;;
    esac
done

JCMD="$JDK_HOME/bin/java -classpath $JARS com.newatlanta.jsp.compiler.JSPCompiler -w $WORK_DIR -r $ROOT_DIR -e $JSP_EXT -u $1 $RECURSE_FLAG"

echo $JCMD
$JCMD

# clear local variables
unset JDK_HOME
unset SE_LIB
unset WORK_DIR
unset ROOT_DIR
unset JSP_EXT
unset JARS
unset RECURSE_FLAG
unset JCMD
